===============================
json_url_rewriter
===============================

.. image:: https://badge.fury.io/py/json_url_rewriter.png
    :target: http://badge.fury.io/py/json_url_rewriter

.. image:: https://travis-ci.org/ionrock/json_url_rewriter.png?branch=master
        :target: https://travis-ci.org/ionrock/json_url_rewriter

.. image:: https://pypip.in/d/json_url_rewriter/badge.png
        :target: https://pypi.python.org/pypi/json_url_rewriter


WSGI Middleware helpers for rewriting links in JSON.

* Free software: BSD license
* Documentation: https://json_url_rewriter.readthedocs.org.

Features
--------

* TODO
